#!/usr/bin/ksh


# IBM Confidential OCO Source Material
# 5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70 (C) COPYRIGHT International Business Machines Corp. 1997, 2008
# The source code for this program is not published or otherwise divested
# of its trade secrets, irrespective of what has been deposited with the
# U.S. Copyright Office.

# DESCRIPTION:
#    Script file used to easily configure WebSphere Plug-in for Apache.


 PLUGIN_HOME=
 OS_NAME=
 APACHE_CONF=
 PLUGIN_CONFIG_XML=
 INSTALL_ARCH="32"
 PLUGIN_INSTALL_TYPE="remote"
 WEBSERVER_NAME="webserver1"

printUsage()
{
        echo ""
        echo ""
        echo "Usage: configureApachePlugin.sh"
        echo "      -plugin.home <pluginInstallRoot>  "
        echo "      -plugin.config.xml <pluginConfigFile>  "
        echo "      -apache.conf.file <confFile>    "
        echo "      -operating.system <operatingSystem>  " 
	echo "    [ -operating.system.arch <arch> ]"
	echo "    [ -WAS.webserver.name <webserverName> ]"
        echo "    [ -help | -? ]"
        echo " "
        echo "Where:"
        echo "    \"plugin.home\" is the plugin install root"
        echo "    \"plugin.config.xml\" is the full path of plugin-config.xml file"
        echo "    \"apache.conf\" is the full path name of the httpd.conf"
        echo "    \"operating.system\" is the name of the operating system"
        echo "        Possible values are: Linux|AIX|HP-UX|SunOS"
        echo "    \"operating.system.arch\" is the architecture of the operating system"
        echo "        Possible values are: 32|64. Default value is 32"
	echo "    \"WAS.webserver.name\" is the name of the webserver as defined "
        echo "        in WebSphere admin console. Default is webserver1"
        echo " "
        echo "Apache Example: "
        echo "    configureApachePlugin.sh -plugin.home /opt/IBM/WebSphere/Plugins"
        echo "      -plugin.config.xml /opt/IBM/WebSphere/Plugins/config/plugin-cfg.xml"
        echo "      -apache.conf.file /opt/apache/conf/httpd.conf"
        echo "      -operating.system AIX "
        echo "      -operating.system.arch 64"
        echo "      -WAS.webserver.name webserver2" 
        echo ""
        echo ""

        exit 0
}

printError()
{
        echo "ERROR: $1"
        printUsage
}

if [ $# -eq 0 ] ; then
   printUsage
fi

 while [ $# -gt 0 ]; do
    case $1 in
              -help|-?)  printUsage 
                         exit 0                
                         ;;
          -plugin.home)  shift
                         PLUGIN_HOME="$1"
                         ;;
     -operating.system)  shift
                         OS_NAME="$1"
                         ;;
     -apache.conf.file)  shift
                         APACHE_CONF="$1"
                         ;;
    -plugin.config.xml)  shift
                         PLUGIN_CONFIG_XML="$1"
                         ;;
   -WAS.webserver.name)  shift
                         WEBSERVER_NAME="$1"
                         ;;
 -operating.system.arch) shift
                         INSTALL_ARCH="$1"
                         ;;
                     -*) echo "Unsupported option $1"
                         printUsage 
                         exit 0                
                         ;;
   esac
   shift
done
${PLUGIN_HOME}/bin/setupCmdLine.sh
${PLUGIN_HOME}/bin/ws_ant.sh -f ${PLUGIN_HOME}/config/actionRegistry/actions/99SBootStrapPluginsApache.ant \
                                     -DPLUGIN_HOME=${PLUGIN_HOME} -DOS_NAME=${OS_NAME} \
                                     -DAPACHE_CONF=${APACHE_CONF} -DWAS_PLUGIN_CFG_XML=${PLUGIN_CONFIG_XML} \
                                     -DINSTALL_ARCH=${INSTALL_ARCH} -DPLUGIN_INSTALL_TYPE=${PLUGIN_INSTALL_TYPE} \
                                     -DWEBSERVER_NAME=${WEBSERVER_NAME} -DWEBSERVER_TYPE=APACHE
                                     
