
#!/usr/bin/ksh

# IBM Confidential OCO Source Material
# 5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70 (C) COPYRIGHT International Business Machines Corp. 1997, 2008
# The source code for this program is not published or otherwise divested
# of its trade secrets, irrespective of what has been deposited with the
# U.S. Copyright Office.                                     

# DESCRIPTION:
#    Script file used to easily configure WebSphere Plug-in for Domino7.

 PLUGIN_HOME=
 OS_NAME=
 DOMINO7_NAMES_CONF=
 DOMINO7_NOTES_CONF=
 PLUGIN_CONFIG_XML=
 INSTALL_ARCH="32"
 PLUGIN_INSTALL_TYPE="remote"
 WEBSERVER_NAME="webserver1"

printUsage()
{
   echo ""
   echo ""
   echo "Usage: configureDomino7Plugin.sh"
   echo "      -plugin.home <pluginInstallRoot>  "
   echo "      -plugin.config.xml <pluginConfigFile>  "
   echo "      -domino7.notes.user <notesLoginID>  "
   echo "      -domino7.names.conf <DOMINO7NamesConf>    "
   echo "      -domino7.notes.conf <DOMINO7NotesConf>    "
   echo "      -operating.system <operatingSystem>  "
   echo "    [ -operating.system.arch <arch> ] "
   echo "    [ -WAS.webserver.name <webserverName>]"
   echo "    [ -help | -? ]"
   echo " "
   echo "Where:"
   echo "    \"plugin.home\" is the plugin install root"
   echo "    \"plugin.config.xml\" is the full path of plugin-config.xml file"
   echo "    \"domino7.notes.user\" is the login name of user that"
   echo "        runs Domino instance"
   echo "    \"domino7.names.conf\" is the full path name of the"
   echo "        Domino7 names.nsf file"
   echo "    \"domino7.notes.conf\" is the full path name of the " 
   echo "        Domino7 Notes.jar file"
   echo "    \"operating.system\" is the name of the operating system"
   echo "        Possible values are: Linux|AIX|HP-UX|SunOS"
   echo "    \"operating.system.arch\" is the architecture of the operating system"
   echo "        Possible values are: 32|64. Default value is 32"
   echo "    \"WAS.webserver.name\" is the name of the webserver as defined "
   echo "        in WebSphere admin console. Default is webserver1"
   echo " "
   echo "DOMINO7 Example: "
   echo "    configureDomino7Plugin.sh -plugin.home /opt/IBM/WebSphere/Plugins"
   echo "      -plugin.config.xml /opt/IBM/WebSphere/Plugins/config/plugin-cfg.xml"
   echo "      -domino7.notes.user root"
   echo "      -domino7.names.conf /opt/lotus/notes/data/names.nsf" 
   echo "      -domino7.notes.conf /opt/lotus/notes/conf/notes.jar"
   echo "      -operating.system AIX  "
   echo "      -operating.system.arch 64 "
   echo "      -plugins.webserver.name webserver2"
   echo " "
   echo " "

   exit 0
}

printError()
{
        echo "ERROR: $1"
        printUsage
}

if [ $# -eq 0 ] ; then
   printUsage
fi

 while [ $# -gt 0 ]; do
    case $1 in
              -help|-?) printUsage 
                        exit 0                
                       ;;
          -plugin.home)  shift
                         PLUGIN_HOME="$1"
                         ;;
     -operating.system)  shift
                         OS_NAME="$1"
                         ;;
   -domino7.notes.user)  shift
                         DOMINO7_NOTES_USER="$1"
                         ;;
   -domino7.names.conf)  shift
                         DOMINO7_NAMES_CONF="$1"
                         ;;
    -domino7.notes.conf) shift
                         DOMINO7_NOTES_CONF="$1"
                         ;;
     -plugin.config.xml) shift
                         PLUGIN_CONFIG_XML="$1"
                         ;;
    -WAS.webserver.name) shift
                         WEBSERVER_NAME="$1"
                         ;;
 -operating.system.arch) shift
                         INSTALL_ARCH="$1"
                         ;;
                     -*) echo "Unsupported option: $1"
                         printUsage 
                         exit 0                
                         ;;
   esac
   shift
done
${PLUGIN_HOME}/bin/setupCmdLine.sh
${PLUGIN_HOME}/bin/ws_ant.sh -f ${PLUGIN_HOME}/config/actionRegistry/actions/99SBootStrapPluginsDomino7.ant \
                                     -DPLUGIN_HOME=${PLUGIN_HOME} -DOS_NAME=${OS_NAME} \
                                     -DDOMINO7_NOTES_USER=${DOMINO7_NOTES_USER}  -DDOMINO7_NAMES_CONF=${DOMINO7_NAMES_CONF} \
                                     -DDOMINO7_NOTES_CONF=${DOMINO7_NOTES_CONF} \
                                     -DWAS_PLUGIN_CFG_XML=${PLUGIN_CONFIG_XML} -DINSTALL_ARCH=${INSTALL_ARCH} -DPLUGIN_INSTALL_TYPE=${PLUGIN_INSTALL_TYPE} \
                                     -DWEBSERVER_NAME=${WEBSERVER_NAME} \
                                     -DWEBSERVER_TYPE=DOMINO -DWEBSERVER_SELECTED=domino7
                                     
                                     

